@@ -27,10 +27,15 @@
 int virBhyveProcessStart(virConnectPtr conn,
                          bhyveConnPtr driver,
                          virDomainObjPtr vm,
-                         virDomainRunningReason reason);
+                         virDomainRunningReason reason,
+                         unsigned int flags);
 
 int virBhyveProcessStop(bhyveConnPtr driver,
                         virDomainObjPtr vm,
                         virDomainShutoffReason reason);
 
+typedef enum {
+    VIR_BHYVE_PROCESS_START_AUTODESTROY = 1 << 0,
+} bhyveProcessStartFlags;
+
 #endif /* __BHYVE_PROCESS_H__ */
