@@ -32,7 +32,7 @@
 # include "virthread.h"
 # include "virbuffer.h"
 
-enum virDeviceAddressPciMulti {
+enum virDeviceAddressPCIMulti {
     VIR_DEVICE_ADDRESS_PCI_MULTI_DEFAULT = 0,
     VIR_DEVICE_ADDRESS_PCI_MULTI_ON,
     VIR_DEVICE_ADDRESS_PCI_MULTI_OFF,
@@ -47,7 +47,7 @@ struct _virDevicePCIAddress {
     unsigned int bus;
     unsigned int slot;
     unsigned int function;
-    int          multi;  /* enum virDomainDeviceAddressPciMulti */
+    int          multi;  /* enum virDomainDeviceAddressPCIMulti */
 };
 
 int virDevicePCIAddressIsValid(virDevicePCIAddressPtr addr);
@@ -63,6 +63,6 @@ bool virDevicePCIAddressEqual(virDevicePCIAddress *addr1,
                               virDevicePCIAddress *addr2);
 
 
-VIR_ENUM_DECL(virDeviceAddressPciMulti)
+VIR_ENUM_DECL(virDeviceAddressPCIMulti)
 
 #endif /* __DEVICE_CONF_H__ */
