@@ -24,6 +24,7 @@
 #include <config.h>
 
 #include "viralloc.h"
+#include "virfile.h"
 #include "cpu.h"
 #include "cpu_map.h"
 #include "configmake.h"
@@ -34,10 +35,6 @@
 
 VIR_LOG_INIT("cpu.cpu_map");
 
-#define CPUMAPFILE PKGDATADIR "/cpu_map.xml"
-
-static char *cpumap;
-
 VIR_ENUM_IMPL(cpuMapElement, CPU_MAP_ELEMENT_LAST,
     "vendor",
     "feature",
@@ -87,20 +84,25 @@ int cpuMapLoad(const char *arch,
     char *xpath = NULL;
     int ret = -1;
     int element;
-    const char *mapfile = (cpumap ? cpumap : CPUMAPFILE);
+    char *mapfile;
+
+    if (!(mapfile = virFileFindResource("cpu_map.xml",
+                                        "src/cpu",
+                                        PKGDATADIR)))
+        return -1;
 
     VIR_DEBUG("Loading CPU map from %s", mapfile);
 
     if (arch == NULL) {
         virReportError(VIR_ERR_INTERNAL_ERROR,
                        "%s", _("undefined hardware architecture"));
-        return -1;
+        goto cleanup;
     }
 
     if (cb == NULL) {
         virReportError(VIR_ERR_INTERNAL_ERROR,
                        "%s", _("no callback provided"));
-        return -1;
+        goto cleanup;
     }
 
     if ((xml = xmlParseFile(mapfile)) == NULL) {
@@ -141,6 +143,7 @@ int cpuMapLoad(const char *arch,
     xmlXPathFreeContext(ctxt);
     xmlFreeDoc(xml);
     VIR_FREE(xpath);
+    VIR_FREE(mapfile);
 
     return ret;
 
@@ -148,17 +151,3 @@ int cpuMapLoad(const char *arch,
     virReportOOMError();
     goto cleanup;
 }
-
-
-int
-cpuMapOverride(const char *path)
-{
-    char *map;
-
-    if (VIR_STRDUP(map, path) < 0)
-        return -1;
-
-    VIR_FREE(cpumap);
-    cpumap = map;
-    return 0;
-}
