@@ -1,4 +1,3 @@
-
 /*
  * hyperv_nwfilter_driver.c: nwfilter driver functions for managing
  *                           Microsoft Hyper-V firewall rules
@@ -26,9 +25,7 @@
 #include "internal.h"
 #include "virerror.h"
 #include "datatypes.h"
-#include "virutil.h"
 #include "viralloc.h"
-#include "virlog.h"
 #include "viruuid.h"
 #include "hyperv_nwfilter_driver.h"
 
