@@ -119,14 +119,10 @@ virNWFilterTechDriverForName(const char *name)
 static void
 virNWFilterRuleInstFree(virNWFilterRuleInstPtr inst)
 {
-    size_t i;
     if (!inst)
         return;
 
-    for (i = 0; i < inst->ndata; i++)
-        inst->techdriver->freeRuleInstance(inst->data[i]);
-
-    VIR_FREE(inst->data);
+    virNWFilterHashTableFree(inst->vars);
     VIR_FREE(inst);
 }
 
@@ -272,52 +268,6 @@ virNWFilterPrintVars(virHashTablePtr vars,
 }
 
 
-/**
- * virNWFilterRuleInstantiate:
- * @techdriver: the driver to use for instantiation
- * @filter: The filter the rule is part of
- * @rule : The rule that is to be instantiated
- * @ifname: The name of the interface
- * @vars: map containing variable names and value used for instantiation
- *
- * Returns virNWFilterRuleInst object on success, NULL on error with
- * error reported.
- *
- * Instantiate a single rule. Return a pointer to virNWFilterRuleInst
- * object that will hold an array of driver-specific data resulting
- * from the instantiation. Returns NULL on error with error reported.
- */
-static virNWFilterRuleInstPtr
-virNWFilterRuleInstantiate(virNWFilterTechDriverPtr techdriver,
-                           enum virDomainNetType nettype,
-                           virNWFilterDefPtr filter,
-                           virNWFilterRuleDefPtr rule,
-                           const char *ifname,
-                           virNWFilterHashTablePtr vars)
-{
-    int rc;
-    size_t i;
-    virNWFilterRuleInstPtr ret;
-
-    if (VIR_ALLOC(ret) < 0)
-        return NULL;
-
-    ret->techdriver = techdriver;
-
-    rc = techdriver->createRuleInstance(nettype, filter,
-                                        rule, ifname, vars, ret);
-
-    if (rc) {
-        for (i = 0; i < ret->ndata; i++)
-            techdriver->freeRuleInstance(ret->data[i]);
-        VIR_FREE(ret);
-        ret = NULL;
-    }
-
-    return ret;
-}
-
-
 /**
  * virNWFilterCreateVarsFrom:
  * @vars1: pointer to hash table
@@ -351,128 +301,198 @@ virNWFilterCreateVarsFrom(virNWFilterHashTablePtr vars1,
 }
 
 
+typedef struct _virNWFilterInst virNWFilterInst;
+typedef virNWFilterInst *virNWFilterInstPtr;
+struct _virNWFilterInst {
+    virNWFilterObjPtr *filters;
+    size_t nfilters;
+    virNWFilterRuleInstPtr *rules;
+    size_t nrules;
+};
+
+
+static void
+virNWFilterInstReset(virNWFilterInstPtr inst)
+{
+    size_t i;
+
+    for (i = 0; i < inst->nfilters; i++)
+        virNWFilterObjUnlock(inst->filters[i]);
+    VIR_FREE(inst->filters);
+    inst->nfilters = 0;
+
+    for (i = 0; i < inst->nrules; i++)
+        virNWFilterRuleInstFree(inst->rules[i]);
+    VIR_FREE(inst->rules);
+}
+
+
+
+static int
+virNWFilterDefToInst(virNWFilterDriverStatePtr driver,
+                     virNWFilterDefPtr def,
+                     virNWFilterHashTablePtr vars,
+                     enum instCase useNewFilter,
+                     bool *foundNewFilter,
+                     virNWFilterInstPtr inst);
+
+static int
+virNWFilterRuleDefToRuleInst(virNWFilterDefPtr def,
+                             virNWFilterRuleDefPtr rule,
+                             virNWFilterHashTablePtr vars,
+                             virNWFilterInstPtr inst)
+{
+    virNWFilterRuleInstPtr ruleinst;
+    int ret = -1;
+
+    if (VIR_ALLOC(ruleinst) < 0)
+        goto cleanup;
+
+    ruleinst->chainSuffix = def->chainsuffix;
+    ruleinst->chainPriority = def->chainPriority;
+    ruleinst->def = rule;
+    ruleinst->priority = rule->priority;
+    if (!(ruleinst->vars = virNWFilterHashTableCreate(0)))
+        goto cleanup;
+    if (virNWFilterHashTablePutAll(vars, ruleinst->vars) < 0)
+        goto cleanup;
+
+    if (VIR_APPEND_ELEMENT(inst->rules,
+                           inst->nrules,
+                           ruleinst) < 0)
+        goto cleanup;
+    inst = NULL;
+
+    ret = 0;
+ cleanup:
+    virNWFilterRuleInstFree(ruleinst);
+    return ret;
+}
+
+
+static int
+virNWFilterIncludeDefToRuleInst(virNWFilterDriverStatePtr driver,
+                                virNWFilterIncludeDefPtr inc,
+                                virNWFilterHashTablePtr vars,
+                                enum instCase useNewFilter,
+                                bool *foundNewFilter,
+                                virNWFilterInstPtr inst)
+{
+    virNWFilterObjPtr obj;
+    virNWFilterHashTablePtr tmpvars = NULL;
+    virNWFilterDefPtr childdef;
+    int ret = -1;
+
+    VIR_DEBUG("Instantiating filter %s", inc->filterref);
+    obj = virNWFilterObjFindByName(&driver->nwfilters,
+                                   inc->filterref);
+    if (!obj) {
+        virReportError(VIR_ERR_INTERNAL_ERROR,
+                       _("referenced filter '%s' is missing"),
+                       inc->filterref);
+        goto cleanup;
+    }
+    if (obj->wantRemoved) {
+        virReportError(VIR_ERR_NO_NWFILTER,
+                       _("Filter '%s' is in use."),
+                       inc->filterref);
+        goto cleanup;
+    }
+
+    /* create a temporary hashmap for depth-first tree traversal */
+    if (!(tmpvars = virNWFilterCreateVarsFrom(inc->params,
+                                              vars)))
+        goto cleanup;
+
+    childdef = obj->def;
+
+    switch (useNewFilter) {
+    case INSTANTIATE_FOLLOW_NEWFILTER:
+        if (obj->newDef) {
+            childdef = obj->newDef;
+            *foundNewFilter = true;
+        }
+        break;
+    case INSTANTIATE_ALWAYS:
+        break;
+    }
+
+    if (VIR_APPEND_ELEMENT(inst->filters,
+                           inst->nfilters,
+                           obj) < 0)
+        goto cleanup;
+    obj = NULL;
+
+    if (virNWFilterDefToInst(driver,
+                             childdef,
+                             tmpvars,
+                             useNewFilter,
+                             foundNewFilter,
+                             inst) < 0)
+        goto cleanup;
+
+    ret = 0;
+ cleanup:
+    if (ret < 0)
+        virNWFilterInstReset(inst);
+    virNWFilterHashTableFree(tmpvars);
+    if (obj)
+        virNWFilterObjUnlock(obj);
+    return ret;
+}
+
+
 /**
- * _virNWFilterInstantiateRec:
- * @techdriver: The driver to use for instantiation
- * @filter: The filter to instantiate
- * @ifname: The name of the interface to apply the rules to
+ * virNWFilterDefToInst:
+ * @driver: the driver state pointer
+ * @def: The filter to instantiate
  * @vars: A map holding variable names and values used for instantiating
  *  the filter and its subfilters.
- * @nEntries: number of virNWFilterInst objects collected
- * @insts: pointer to array for virNWFilterIns object pointers
  * @useNewFilter: instruct whether to use a newDef pointer rather than a
  *  def ptr which is useful during a filter update
  * @foundNewFilter: pointer to int indivating whether a newDef pointer was
  *  ever used; variable expected to be initialized to 0 by caller
+ * @rulesout: array to be filled with rule instance
+ * @nrulesout: counter to be filled with number of rule instances
  *
- * Returns 0 on success, a value otherwise.
+ * Recursively expand a nested filter into a flat list of rule instances,
+ * in a depth-first traversal of the tree.
  *
- * Recursively instantiate a filter by instantiating the given filter along
- * with all its subfilters in a depth-first traversal of the tree of
- * referenced filters. The name of the interface to which the rules belong
- * must be provided. Apply the values of variables as needed. Terminate with
- * error when a referenced filter is missing or a variable could not be
- * resolved -- among other reasons.
+ * Returns 0 on success, -1 on error
  */
 static int
-_virNWFilterInstantiateRec(virNWFilterTechDriverPtr techdriver,
-                           enum virDomainNetType nettype,
-                           virNWFilterDefPtr filter,
-                           const char *ifname,
-                           virNWFilterHashTablePtr vars,
-                           size_t *nEntries,
-                           virNWFilterRuleInstPtr **insts,
-                           enum instCase useNewFilter, bool *foundNewFilter,
-                           virNWFilterDriverStatePtr driver)
+virNWFilterDefToInst(virNWFilterDriverStatePtr driver,
+                     virNWFilterDefPtr def,
+                     virNWFilterHashTablePtr vars,
+                     enum instCase useNewFilter,
+                     bool *foundNewFilter,
+                     virNWFilterInstPtr inst)
 {
-    virNWFilterObjPtr obj;
-    int rc = 0;
     size_t i;
-    virNWFilterRuleInstPtr inst;
-    virNWFilterDefPtr next_filter;
+    int ret = -1;
 
-    for (i = 0; i < filter->nentries; i++) {
-        virNWFilterRuleDefPtr    rule = filter->filterEntries[i]->rule;
-        virNWFilterIncludeDefPtr inc  = filter->filterEntries[i]->include;
-        if (rule) {
-            inst = virNWFilterRuleInstantiate(techdriver,
-                                              nettype,
-                                              filter,
-                                              rule,
-                                              ifname,
-                                              vars);
-            if (!inst) {
-                rc = -1;
-                break;
-            }
-
-            if (VIR_APPEND_ELEMENT_COPY(*insts, *nEntries, inst) < 0) {
-                rc = -1;
-                break;
-            }
-
-        } else if (inc) {
-            VIR_DEBUG("Instantiating filter %s", inc->filterref);
-            obj = virNWFilterObjFindByName(&driver->nwfilters, inc->filterref);
-            if (obj) {
-
-                if (obj->wantRemoved) {
-                    virReportError(VIR_ERR_NO_NWFILTER,
-                                   _("Filter '%s' is in use."),
-                                   inc->filterref);
-                    rc = -1;
-                    virNWFilterObjUnlock(obj);
-                    break;
-                }
-
-                /* create a temporary hashmap for depth-first tree traversal */
-                virNWFilterHashTablePtr tmpvars =
-                                      virNWFilterCreateVarsFrom(inc->params,
-                                                                vars);
-                if (!tmpvars) {
-                    rc = -1;
-                    virNWFilterObjUnlock(obj);
-                    break;
-                }
-
-                next_filter = obj->def;
-
-                switch (useNewFilter) {
-                case INSTANTIATE_FOLLOW_NEWFILTER:
-                    if (obj->newDef) {
-                        next_filter = obj->newDef;
-                        *foundNewFilter = true;
-                    }
-                break;
-                case INSTANTIATE_ALWAYS:
-                break;
-                }
-
-                rc = _virNWFilterInstantiateRec(techdriver,
-                                                nettype,
-                                                next_filter,
-                                                ifname,
-                                                tmpvars,
-                                                nEntries, insts,
-                                                useNewFilter,
-                                                foundNewFilter,
-                                                driver);
-
-                virNWFilterHashTableFree(tmpvars);
-
-                virNWFilterObjUnlock(obj);
-                if (rc < 0)
-                    break;
-            } else {
-                virReportError(VIR_ERR_INTERNAL_ERROR,
-                               _("referenced filter '%s' is missing"),
-                               inc->filterref);
-                rc = -1;
-                break;
-            }
+    for (i = 0; i < def->nentries; i++) {
+        if (def->filterEntries[i]->rule) {
+            if (virNWFilterRuleDefToRuleInst(def,
+                                             def->filterEntries[i]->rule,
+                                             vars,
+                                             inst) < 0)
+                goto cleanup;
+        } else if (def->filterEntries[i]->include) {
+            if (virNWFilterIncludeDefToRuleInst(driver,
+                                                def->filterEntries[i]->include,
+                                                vars,
+                                                useNewFilter, foundNewFilter,
+                                                inst) < 0)
+                goto cleanup;
         }
     }
-    return rc;
+
+    ret = 0;
+ cleanup:
+    if (ret < 0)
+        virNWFilterInstReset(inst);
+    return ret;
 }
 
 
@@ -516,7 +536,7 @@ virNWFilterDetermineMissingVarsRec(virNWFilterDefPtr filter,
 
                     varAccess = virBufferContentAndReset(&buf);
                     virNWFilterHashTablePut(missing_vars, varAccess,
-                                            val, 1);
+                                            val);
                     VIR_FREE(varAccess);
                 }
             }
@@ -582,35 +602,6 @@ virNWFilterDetermineMissingVarsRec(virNWFilterDefPtr filter,
 }
 
 
-static int
-virNWFilterRuleInstancesToArray(int nEntries,
-                                virNWFilterRuleInstPtr *insts,
-                                void ***ptrs,
-                                int *nptrs)
-{
-    size_t i, j;
-
-    *nptrs = 0;
-
-    for (j = 0; j < nEntries; j++)
-        (*nptrs) += insts[j]->ndata;
-
-    if ((*nptrs) == 0)
-        return 0;
-
-    if (VIR_ALLOC_N((*ptrs), (*nptrs)) < 0)
-        return -1;
-
-    (*nptrs) = 0;
-
-    for (j = 0; j < nEntries; j++)
-        for (i = 0; i < insts[j]->ndata; i++)
-            (*ptrs)[(*nptrs)++] = insts[j]->data[i];
-
-    return 0;
-}
-
-
 /**
  * virNWFilterInstantiate:
  * @vmuuid: The UUID of the VM
@@ -634,7 +625,6 @@ virNWFilterRuleInstancesToArray(int nEntries,
 static int
 virNWFilterInstantiate(const unsigned char *vmuuid ATTRIBUTE_UNUSED,
                        virNWFilterTechDriverPtr techdriver,
-                       enum virDomainNetType nettype,
                        virNWFilterDefPtr filter,
                        const char *ifname,
                        int ifindex,
@@ -647,11 +637,7 @@ virNWFilterInstantiate(const unsigned char *vmuuid ATTRIBUTE_UNUSED,
                        bool forceWithPendingReq)
 {
     int rc;
-    size_t j;
-    int nptrs;
-    size_t nEntries = 0;
-    virNWFilterRuleInstPtr *insts = NULL;
-    void **ptrs = NULL;
+    virNWFilterInst inst;
     bool instantiate = true;
     char *buf;
     virNWFilterVarValuePtr lv;
@@ -659,6 +645,9 @@ virNWFilterInstantiate(const unsigned char *vmuuid ATTRIBUTE_UNUSED,
     bool reportIP = false;
 
     virNWFilterHashTablePtr missing_vars = virNWFilterHashTableCreate(0);
+
+    memset(&inst, 0, sizeof(inst));
+
     if (!missing_vars) {
         rc = -1;
         goto err_exit;
@@ -690,7 +679,7 @@ virNWFilterInstantiate(const unsigned char *vmuuid ATTRIBUTE_UNUSED,
             }
             if (STRCASEEQ(learning, "dhcp")) {
                 rc = virNWFilterDHCPSnoopReq(techdriver, ifname, linkdev,
-                                             nettype, vmuuid, macaddr,
+                                             vmuuid, macaddr,
                                              filter->name, vars, driver);
                 goto err_exit;
             } else if (STRCASEEQ(learning, "any")) {
@@ -699,7 +688,7 @@ virNWFilterInstantiate(const unsigned char *vmuuid ATTRIBUTE_UNUSED,
                                                    ifname,
                                                    ifindex,
                                                    linkdev,
-                                                   nettype, macaddr,
+                                                   macaddr,
                                                    filter->name,
                                                    vars, driver,
                                                    DETECT_DHCP|DETECT_STATIC);
@@ -722,14 +711,11 @@ virNWFilterInstantiate(const unsigned char *vmuuid ATTRIBUTE_UNUSED,
         goto err_exit;
     }
 
-    rc = _virNWFilterInstantiateRec(techdriver,
-                                    nettype,
-                                    filter,
-                                    ifname,
-                                    vars,
-                                    &nEntries, &insts,
-                                    useNewFilter, foundNewFilter,
-                                    driver);
+    rc = virNWFilterDefToInst(driver,
+                              filter,
+                              vars,
+                              useNewFilter, foundNewFilter,
+                              &inst);
 
     if (rc < 0)
         goto err_exit;
@@ -744,16 +730,10 @@ virNWFilterInstantiate(const unsigned char *vmuuid ATTRIBUTE_UNUSED,
     }
 
     if (instantiate) {
-
-        rc = virNWFilterRuleInstancesToArray(nEntries, insts,
-                                             &ptrs, &nptrs);
-        if (rc < 0)
-            goto err_exit;
-
         if (virNWFilterLockIface(ifname) < 0)
             goto err_exit;
 
-        rc = techdriver->applyNewRules(ifname, nptrs, ptrs);
+        rc = techdriver->applyNewRules(ifname, inst.rules, inst.nrules);
 
         if (teardownOld && rc == 0)
             techdriver->tearOldRules(ifname);
@@ -769,13 +749,7 @@ virNWFilterInstantiate(const unsigned char *vmuuid ATTRIBUTE_UNUSED,
     }
 
  err_exit:
-
-    for (j = 0; j < nEntries; j++)
-        virNWFilterRuleInstFree(insts[j]);
-
-    VIR_FREE(insts);
-    VIR_FREE(ptrs);
-
+    virNWFilterInstReset(&inst);
     virNWFilterHashTableFree(missing_vars);
 
     return rc;
@@ -805,7 +779,6 @@ __virNWFilterInstantiateFilter(virNWFilterDriverStatePtr driver,
                                const char *ifname,
                                int ifindex,
                                const char *linkdev,
-                               enum virDomainNetType nettype,
                                const virMacAddr *macaddr,
                                const char *filtername,
                                virNWFilterHashTablePtr filterparams,
@@ -892,7 +865,6 @@ __virNWFilterInstantiateFilter(virNWFilterDriverStatePtr driver,
 
     rc = virNWFilterInstantiate(vmuuid,
                                 techdriver,
-                                nettype,
                                 filter,
                                 ifname,
                                 ifindex,
@@ -953,7 +925,6 @@ _virNWFilterInstantiateFilter(virNWFilterDriverStatePtr driver,
                                         net->ifname,
                                         ifindex,
                                         linkdev,
-                                        net->type,
                                         &net->mac,
                                         net->filter,
                                         net->filterparams,
@@ -974,7 +945,6 @@ virNWFilterInstantiateFilterLate(virNWFilterDriverStatePtr driver,
                                  const char *ifname,
                                  int ifindex,
                                  const char *linkdev,
-                                 enum virDomainNetType nettype,
                                  const virMacAddr *macaddr,
                                  const char *filtername,
                                  virNWFilterHashTablePtr filterparams)
@@ -991,7 +961,6 @@ virNWFilterInstantiateFilterLate(virNWFilterDriverStatePtr driver,
                                         ifname,
                                         ifindex,
                                         linkdev,
-                                        nettype,
                                         macaddr,
                                         filtername,
                                         filterparams,
