@@ -1753,7 +1753,7 @@ int qemuMonitorTextAddUSBDeviceMatch(qemuMonitorPtr mon,
 
 
 static int
-qemuMonitorTextParsePciAddReply(qemuMonitorPtr mon ATTRIBUTE_UNUSED,
+qemuMonitorTextParsePCIAddReply(qemuMonitorPtr mon ATTRIBUTE_UNUSED,
                                 const char *reply,
                                 virDevicePCIAddress *addr)
 {
@@ -1840,7 +1840,7 @@ int qemuMonitorTextAddPCIHostDevice(qemuMonitorPtr mon,
         goto cleanup;
     }
 
-    if (qemuMonitorTextParsePciAddReply(mon, reply, guestAddr) < 0) {
+    if (qemuMonitorTextParsePCIAddReply(mon, reply, guestAddr) < 0) {
         virReportError(VIR_ERR_OPERATION_FAILED,
                        _("parsing pci_add reply failed: %s"), reply);
         goto cleanup;
@@ -1878,7 +1878,7 @@ int qemuMonitorTextAddPCIDisk(qemuMonitorPtr mon,
     if (qemuMonitorHMPCommand(mon, cmd, &reply) < 0)
         goto cleanup;
 
-    if (qemuMonitorTextParsePciAddReply(mon, reply, guestAddr) < 0) {
+    if (qemuMonitorTextParsePCIAddReply(mon, reply, guestAddr) < 0) {
         if (!tryOldSyntax && strstr(reply, "invalid char in expression")) {
             VIR_FREE(reply);
             VIR_FREE(cmd);
@@ -1915,7 +1915,7 @@ int qemuMonitorTextAddPCINetwork(qemuMonitorPtr mon,
     if (qemuMonitorHMPCommand(mon, cmd, &reply) < 0)
         goto cleanup;
 
-    if (qemuMonitorTextParsePciAddReply(mon, reply, guestAddr) < 0) {
+    if (qemuMonitorTextParsePCIAddReply(mon, reply, guestAddr) < 0) {
         virReportError(VIR_ERR_OPERATION_FAILED,
                        _("parsing pci_add reply failed: %s"), reply);
         goto cleanup;
@@ -2252,7 +2252,7 @@ int qemuMonitorTextAttachPCIDiskController(qemuMonitorPtr mon,
     if (qemuMonitorHMPCommand(mon, cmd, &reply) < 0)
         goto cleanup;
 
-    if (qemuMonitorTextParsePciAddReply(mon, reply, guestAddr) < 0) {
+    if (qemuMonitorTextParsePCIAddReply(mon, reply, guestAddr) < 0) {
         if (!tryOldSyntax && strstr(reply, "invalid char in expression")) {
             VIR_FREE(reply);
             VIR_FREE(cmd);
