@@ -55,6 +55,7 @@
 #include "virfile.h"
 #include "stat-time.h"
 #include "virstring.h"
+#include "virxml.h"
 
 #if WITH_STORAGE_LVM
 # include "storage_backend_logical.h"
@@ -287,7 +288,7 @@ virStorageBackendCreateBlockFrom(virConnectPtr conn ATTRIBUTE_UNUSED,
         goto cleanup;
     }
 
-    remain = vol->allocation;
+    remain = vol->target.allocation;
 
     if (inputvol) {
         int res = virStorageBackendCopyToFD(vol, inputvol,
@@ -301,8 +302,10 @@ virStorageBackendCreateBlockFrom(virConnectPtr conn ATTRIBUTE_UNUSED,
                              vol->target.path);
         goto cleanup;
     }
-    uid = (vol->target.perms.uid != st.st_uid) ? vol->target.perms.uid : (uid_t) -1;
-    gid = (vol->target.perms.gid != st.st_gid) ? vol->target.perms.gid : (gid_t) -1;
+    uid = (vol->target.perms->uid != st.st_uid) ? vol->target.perms->uid
+        : (uid_t) -1;
+    gid = (vol->target.perms->gid != st.st_gid) ? vol->target.perms->gid
+        : (gid_t) -1;
     if (((uid != (uid_t) -1) || (gid != (gid_t) -1))
         && (fchown(fd, uid, gid) < 0)) {
         virReportSystemError(errno,
@@ -311,10 +314,10 @@ virStorageBackendCreateBlockFrom(virConnectPtr conn ATTRIBUTE_UNUSED,
                              (unsigned int) gid);
         goto cleanup;
     }
-    if (fchmod(fd, vol->target.perms.mode) < 0) {
+    if (fchmod(fd, vol->target.perms->mode) < 0) {
         virReportSystemError(errno,
                              _("cannot set mode of '%s' to %04o"),
-                             vol->target.path, vol->target.perms.mode);
+                             vol->target.path, vol->target.perms->mode);
         goto cleanup;
     }
     if (VIR_CLOSE(fd) < 0) {
@@ -342,7 +345,7 @@ createRawFile(int fd, virStorageVolDefPtr vol,
 
     /* Seek to the final size, so the capacity is available upfront
      * for progress reporting */
-    if (ftruncate(fd, vol->capacity) < 0) {
+    if (ftruncate(fd, vol->target.capacity) < 0) {
         ret = -errno;
         virReportSystemError(errno,
                              _("cannot extend file '%s'"),
@@ -359,27 +362,27 @@ createRawFile(int fd, virStorageVolDefPtr vol,
      * to writing zeroes block by block in case fallocate isn't
      * available, and since we're going to copy data from another
      * file it doesn't make sense to write the file twice. */
-    if (vol->allocation) {
-        if (fallocate(fd, 0, 0, vol->allocation) == 0) {
+    if (vol->target.allocation) {
+        if (fallocate(fd, 0, 0, vol->target.allocation) == 0) {
             need_alloc = false;
         } else if (errno != ENOSYS && errno != EOPNOTSUPP) {
             ret = -errno;
             virReportSystemError(errno,
                                  _("cannot allocate %llu bytes in file '%s'"),
-                                 vol->allocation, vol->target.path);
+                                 vol->target.allocation, vol->target.path);
             goto cleanup;
         }
     }
 #endif
 
-    remain = vol->allocation;
+    remain = vol->target.allocation;
 
     if (inputvol) {
         /* allow zero blocks to be skipped if we've requested sparse
          * allocation (allocation < capacity) or we have already
          * been able to allocate the required space. */
         bool want_sparse = !need_alloc ||
-                           (vol->allocation < inputvol->capacity);
+            (vol->target.allocation < inputvol->target.capacity);
 
         ret = virStorageBackendCopyToFD(vol, inputvol, fd, &remain, want_sparse);
         if (ret < 0) {
@@ -388,7 +391,7 @@ createRawFile(int fd, virStorageVolDefPtr vol,
     }
 
     if (remain && need_alloc) {
-        if (safezero(fd, vol->allocation - remain, remain) < 0) {
+        if (safezero(fd, vol->target.allocation - remain, remain) < 0) {
             ret = -errno;
             virReportSystemError(errno, _("cannot fill file '%s'"),
                                  vol->target.path);
@@ -439,9 +442,9 @@ virStorageBackendCreateRaw(virConnectPtr conn ATTRIBUTE_UNUSED,
 
     if ((fd = virFileOpenAs(vol->target.path,
                             O_RDWR | O_CREAT | O_EXCL,
-                            vol->target.perms.mode,
-                            vol->target.perms.uid,
-                            vol->target.perms.gid,
+                            vol->target.perms->mode,
+                            vol->target.perms->uid,
+                            vol->target.perms->gid,
                             operation_flags)) < 0) {
         virReportSystemError(-fd,
                              _("Failed to create file '%s'"),
@@ -479,7 +482,7 @@ virStorageGenerateSecretUUID(virConnectPtr conn,
     }
 
     virReportError(VIR_ERR_INTERNAL_ERROR, "%s",
-                   _("too many conflicts when generating an uuid"));
+                   _("too many conflicts when generating a uuid"));
 
     return -1;
 }
@@ -578,13 +581,13 @@ virStorageBackendCreateExecCommand(virStoragePoolObjPtr pool,
 
     if ((pool->def->type == VIR_STORAGE_POOL_NETFS)
         && (((geteuid() == 0)
-             && (vol->target.perms.uid != (uid_t) -1)
-             && (vol->target.perms.uid != 0))
-            || ((vol->target.perms.gid != (gid_t) -1)
-                && (vol->target.perms.gid != getegid())))) {
+             && (vol->target.perms->uid != (uid_t) -1)
+             && (vol->target.perms->uid != 0))
+            || ((vol->target.perms->gid != (gid_t) -1)
+                && (vol->target.perms->gid != getegid())))) {
 
-        virCommandSetUID(cmd, vol->target.perms.uid);
-        virCommandSetGID(cmd, vol->target.perms.gid);
+        virCommandSetUID(cmd, vol->target.perms->uid);
+        virCommandSetGID(cmd, vol->target.perms->gid);
 
         if (virCommandRun(cmd, NULL) == 0) {
             /* command was successfully run, check if the file was created */
@@ -608,8 +611,10 @@ virStorageBackendCreateExecCommand(virStoragePoolObjPtr pool,
         }
     }
 
-    uid = (vol->target.perms.uid != st.st_uid) ? vol->target.perms.uid : (uid_t) -1;
-    gid = (vol->target.perms.gid != st.st_gid) ? vol->target.perms.gid : (gid_t) -1;
+    uid = (vol->target.perms->uid != st.st_uid) ? vol->target.perms->uid
+        : (uid_t) -1;
+    gid = (vol->target.perms->gid != st.st_gid) ? vol->target.perms->gid
+        : (gid_t) -1;
     if (((uid != (uid_t) -1) || (gid != (gid_t) -1))
         && (chown(vol->target.path, uid, gid) < 0)) {
         virReportSystemError(errno,
@@ -618,10 +623,10 @@ virStorageBackendCreateExecCommand(virStoragePoolObjPtr pool,
                              (unsigned int) gid);
         return -1;
     }
-    if (chmod(vol->target.path, vol->target.perms.mode) < 0) {
+    if (chmod(vol->target.path, vol->target.perms->mode) < 0) {
         virReportSystemError(errno,
                              _("cannot set mode of '%s' to %04o"),
-                             vol->target.path, vol->target.perms.mode);
+                             vol->target.path, vol->target.perms->mode);
         return -1;
     }
     return 0;
@@ -920,7 +925,7 @@ virStorageBackendCreateQemuImgCmd(virConnectPtr conn,
     }
 
     /* Size in KB */
-    size_arg = VIR_DIV_UP(vol->capacity, 1024);
+    size_arg = VIR_DIV_UP(vol->target.capacity, 1024);
 
     cmd = virCommandNew(create_tool);
 
@@ -1066,7 +1071,7 @@ virStorageBackendCreateQcowCreate(virConnectPtr conn ATTRIBUTE_UNUSED,
 
     /* Size in MB - yes different units to qemu-img :-( */
     if (virAsprintf(&size, "%llu",
-                    VIR_DIV_UP(vol->capacity, (1024 * 1024))) < 0)
+                    VIR_DIV_UP(vol->target.capacity, (1024 * 1024))) < 0)
         return -1;
 
     cmd = virCommandNewArgList("qcow-create", size, vol->target.path, NULL);
@@ -1175,7 +1180,7 @@ virStorageFileBackendForType(int type,
 
     for (i = 0; fileBackends[i]; i++) {
         if (fileBackends[i]->type == type) {
-            if (type == VIR_DOMAIN_DISK_TYPE_NETWORK &&
+            if (type == VIR_STORAGE_TYPE_NETWORK &&
                 fileBackends[i]->protocol != protocol)
                 continue;
 
@@ -1183,15 +1188,15 @@ virStorageFileBackendForType(int type,
         }
     }
 
-    if (type == VIR_DOMAIN_DISK_TYPE_NETWORK) {
+    if (type == VIR_STORAGE_TYPE_NETWORK) {
         virReportError(VIR_ERR_INTERNAL_ERROR,
                        _("missing storage backend for network files "
                          "using %s protocol"),
-                       virDomainDiskProtocolTypeToString(protocol));
+                       virStorageNetProtocolTypeToString(protocol));
     } else {
         virReportError(VIR_ERR_INTERNAL_ERROR,
                        _("missing storage backend for '%s' storage"),
-                       virDomainDiskTypeToString(type));
+                       virStorageTypeToString(type));
     }
 
     return NULL;
@@ -1232,7 +1237,7 @@ static struct diskType const disk_types[] = {
 
 
 static int
-virStorageBackendDetectBlockVolFormatFD(virStorageVolTargetPtr target,
+virStorageBackendDetectBlockVolFormatFD(virStorageSourcePtr target,
                                         int fd)
 {
     size_t i;
@@ -1275,8 +1280,9 @@ virStorageBackendDetectBlockVolFormatFD(virStorageVolTargetPtr target,
 /*
  * Allows caller to silently ignore files with improper mode
  *
- * Returns -1 on error, -2 if file mode is unexpected or the
- * volume is a dangling symbolic link.
+ * Returns -1 on error. If VIR_STORAGE_VOL_OPEN_NOERROR is passed, we
+ * return -2 if file mode is unexpected or the volume is a dangling
+ * symbolic link.
  */
 int
 virStorageBackendVolOpen(const char *path, struct stat *sb,
@@ -1284,9 +1290,10 @@ virStorageBackendVolOpen(const char *path, struct stat *sb,
 {
     int fd, mode = 0;
     char *base = last_component(path);
+    bool noerror = (flags & VIR_STORAGE_VOL_OPEN_NOERROR);
 
     if (lstat(path, sb) < 0) {
-        if (errno == ENOENT && !(flags & VIR_STORAGE_VOL_OPEN_ERROR)) {
+        if (errno == ENOENT && noerror) {
             VIR_WARN("ignoring missing file '%s'", path);
             return -2;
         }
@@ -1297,11 +1304,21 @@ virStorageBackendVolOpen(const char *path, struct stat *sb,
     }
 
     if (S_ISFIFO(sb->st_mode)) {
-        VIR_WARN("ignoring FIFO '%s'", path);
-        return -2;
+        if (noerror) {
+            VIR_WARN("ignoring FIFO '%s'", path);
+            return -2;
+        }
+        virReportError(VIR_ERR_INTERNAL_ERROR,
+                       _("Volume path '%s' is a FIFO"), path);
+        return -1;
     } else if (S_ISSOCK(sb->st_mode)) {
-        VIR_WARN("ignoring socket '%s'", path);
-        return -2;
+        if (noerror) {
+            VIR_WARN("ignoring socket '%s'", path);
+            return -2;
+        }
+        virReportError(VIR_ERR_INTERNAL_ERROR,
+                       _("Volume path '%s' is a socket"), path);
+        return -1;
     }
 
     /* O_NONBLOCK should only matter during open() for fifos and
@@ -1312,25 +1329,21 @@ virStorageBackendVolOpen(const char *path, struct stat *sb,
      * race.  */
     if ((fd = open(path, O_RDONLY|O_NONBLOCK|O_NOCTTY)) < 0) {
         if ((errno == ENOENT || errno == ELOOP) &&
-            S_ISLNK(sb->st_mode)) {
+            S_ISLNK(sb->st_mode) && noerror) {
             VIR_WARN("ignoring dangling symlink '%s'", path);
             return -2;
         }
-        if (errno == ENOENT && !(flags & VIR_STORAGE_VOL_OPEN_ERROR)) {
+        if (errno == ENOENT && noerror) {
             VIR_WARN("ignoring missing file '%s'", path);
             return -2;
         }
 
-        virReportSystemError(errno,
-                             _("cannot open volume '%s'"),
-                             path);
+        virReportSystemError(errno, _("cannot open volume '%s'"), path);
         return -1;
     }
 
     if (fstat(fd, sb) < 0) {
-        virReportSystemError(errno,
-                             _("cannot stat file '%s'"),
-                             path);
+        virReportSystemError(errno, _("cannot stat file '%s'"), path);
         VIR_FORCE_CLOSE(fd);
         return -1;
     }
@@ -1347,42 +1360,50 @@ virStorageBackendVolOpen(const char *path, struct stat *sb,
         if (STREQ(base, ".") ||
             STREQ(base, "..")) {
             VIR_FORCE_CLOSE(fd);
-            VIR_INFO("Skipping special dir '%s'", base);
-            return -2;
+            if (noerror) {
+                VIR_INFO("Skipping special dir '%s'", base);
+                return -2;
+            }
+            virReportError(VIR_ERR_INTERNAL_ERROR,
+                           _("Cannot use volume path '%s'"), path);
+            return -1;
         }
     } else {
-        VIR_WARN("ignoring unexpected type for file '%s'", path);
         VIR_FORCE_CLOSE(fd);
-        return -2;
+        if (noerror) {
+            VIR_WARN("ignoring unexpected type for file '%s'", path);
+            return -2;
+        }
+        virReportError(VIR_ERR_INTERNAL_ERROR,
+                       _("unexpected type for file '%s'"), path);
+        return -1;
     }
 
     if (virSetBlocking(fd, true) < 0) {
+        VIR_FORCE_CLOSE(fd);
         virReportSystemError(errno, _("unable to set blocking mode for '%s'"),
                              path);
-        VIR_FORCE_CLOSE(fd);
-        return -2;
+        return -1;
     }
 
     if (!(mode & flags)) {
         VIR_FORCE_CLOSE(fd);
-        VIR_INFO("Skipping volume '%s'", path);
-
-        if (mode & VIR_STORAGE_VOL_OPEN_ERROR) {
-            virReportError(VIR_ERR_INTERNAL_ERROR,
-                           _("unexpected storage mode for '%s'"), path);
-            return -1;
+        if (noerror) {
+            VIR_INFO("Skipping volume '%s'", path);
+            return -2;
         }
 
-        return -2;
+        virReportError(VIR_ERR_INTERNAL_ERROR,
+                       _("unexpected storage mode for '%s'"), path);
+        return -1;
     }
 
     return fd;
 }
 
 int
-virStorageBackendUpdateVolTargetInfo(virStorageVolTargetPtr target,
-                                     unsigned long long *allocation,
-                                     unsigned long long *capacity,
+virStorageBackendUpdateVolTargetInfo(virStorageSourcePtr target,
+                                     bool updateCapacity,
                                      bool withBlockVolFormat,
                                      unsigned int openflags)
 {
@@ -1393,11 +1414,8 @@ virStorageBackendUpdateVolTargetInfo(virStorageVolTargetPtr target,
         goto cleanup;
     fd = ret;
 
-    if ((ret = virStorageBackendUpdateVolTargetInfoFD(target,
-                                                      fd,
-                                                      &sb,
-                                                      allocation,
-                                                      capacity)) < 0)
+    if ((ret = virStorageBackendUpdateVolTargetInfoFD(target, fd, &sb,
+                                                      updateCapacity)) < 0)
         goto cleanup;
 
     if (withBlockVolFormat) {
@@ -1413,22 +1431,21 @@ virStorageBackendUpdateVolTargetInfo(virStorageVolTargetPtr target,
 
 int
 virStorageBackendUpdateVolInfo(virStorageVolDefPtr vol,
-                               bool withCapacity,
+                               bool updateCapacity,
                                bool withBlockVolFormat,
                                unsigned int openflags)
 {
     int ret;
 
     if ((ret = virStorageBackendUpdateVolTargetInfo(&vol->target,
-                                    &vol->allocation,
-                                    withCapacity ? &vol->capacity : NULL,
+                                    updateCapacity,
                                     withBlockVolFormat,
                                     openflags)) < 0)
         return ret;
 
     if (vol->backingStore.path &&
         (ret = virStorageBackendUpdateVolTargetInfo(&vol->backingStore,
-                                            NULL, NULL,
+                                            updateCapacity,
                                             withBlockVolFormat,
                                             VIR_STORAGE_VOL_OPEN_DEFAULT)) < 0)
         return ret;
@@ -1441,63 +1458,60 @@ virStorageBackendUpdateVolInfo(virStorageVolDefPtr vol,
  * @target: target definition ptr of volume to update
  * @fd: fd of storage volume to update, via virStorageBackendOpenVol*, or -1
  * @sb: details about file (must match @fd, if that is provided)
- * @allocation: If not NULL, updated allocation information will be stored
- * @capacity: If not NULL, updated capacity info will be stored
+ * @updateCapacity: If true, updated capacity info will be stored
  *
  * Returns 0 for success, -1 on a legitimate error condition.
  */
 int
-virStorageBackendUpdateVolTargetInfoFD(virStorageVolTargetPtr target,
+virStorageBackendUpdateVolTargetInfoFD(virStorageSourcePtr target,
                                        int fd,
                                        struct stat *sb,
-                                       unsigned long long *allocation,
-                                       unsigned long long *capacity)
+                                       bool updateCapacity)
 {
 #if WITH_SELINUX
     security_context_t filecon = NULL;
 #endif
 
-    if (allocation) {
-        if (S_ISREG(sb->st_mode)) {
+    if (S_ISREG(sb->st_mode)) {
 #ifndef WIN32
-            *allocation = (unsigned long long)sb->st_blocks *
-                          (unsigned long long)DEV_BSIZE;
+        target->allocation = (unsigned long long)sb->st_blocks *
+            (unsigned long long)DEV_BSIZE;
 #else
-            *allocation = sb->st_size;
+        target->allocation = sb->st_size;
 #endif
-            /* Regular files may be sparse, so logical size (capacity) is not same
-             * as actual allocation above
-             */
-            if (capacity)
-                *capacity = sb->st_size;
-        } else if (S_ISDIR(sb->st_mode)) {
-            *allocation = 0;
-            if (capacity)
-                *capacity = 0;
-
-        } else if (fd >= 0) {
-            off_t end;
-            /* XXX this is POSIX compliant, but doesn't work for CHAR files,
-             * only BLOCK. There is a Linux specific ioctl() for getting
-             * size of both CHAR / BLOCK devices we should check for in
-             * configure
-             */
-            end = lseek(fd, 0, SEEK_END);
-            if (end == (off_t)-1) {
-                virReportSystemError(errno,
-                                     _("cannot seek to end of file '%s'"),
-                                     target->path);
-                return -1;
-            }
-            *allocation = end;
-            if (capacity)
-                *capacity = end;
+        /* Regular files may be sparse, so logical size (capacity) is not same
+         * as actual allocation above
+         */
+        if (updateCapacity)
+            target->capacity = sb->st_size;
+    } else if (S_ISDIR(sb->st_mode)) {
+        target->allocation = 0;
+        if (updateCapacity)
+            target->capacity = 0;
+    } else if (fd >= 0) {
+        off_t end;
+        /* XXX this is POSIX compliant, but doesn't work for CHAR files,
+         * only BLOCK. There is a Linux specific ioctl() for getting
+         * size of both CHAR / BLOCK devices we should check for in
+         * configure
+         */
+        end = lseek(fd, 0, SEEK_END);
+        if (end == (off_t)-1) {
+            virReportSystemError(errno,
+                                 _("cannot seek to end of file '%s'"),
+                                 target->path);
+            return -1;
         }
+        target->allocation = end;
+        if (updateCapacity)
+            target->capacity = end;
     }
 
-    target->perms.mode = sb->st_mode & S_IRWXUGO;
-    target->perms.uid = sb->st_uid;
-    target->perms.gid = sb->st_gid;
+    if (!target->perms && VIR_ALLOC(target->perms) < 0)
+        return -1;
+    target->perms->mode = sb->st_mode & S_IRWXUGO;
+    target->perms->uid = sb->st_uid;
+    target->perms->gid = sb->st_gid;
 
     if (!target->timestamps && VIR_ALLOC(target->timestamps) < 0)
         return -1;
@@ -1506,7 +1520,7 @@ virStorageBackendUpdateVolTargetInfoFD(virStorageVolTargetPtr target,
     target->timestamps->ctime = get_stat_ctime(sb);
     target->timestamps->mtime = get_stat_mtime(sb);
 
-    VIR_FREE(target->perms.label);
+    VIR_FREE(target->perms->label);
 
 #if WITH_SELINUX
     /* XXX: make this a security driver call */
@@ -1519,7 +1533,7 @@ virStorageBackendUpdateVolTargetInfoFD(virStorageVolTargetPtr target,
                 return -1;
             }
         } else {
-            if (VIR_STRDUP(target->perms.label, filecon) < 0) {
+            if (VIR_STRDUP(target->perms->label, filecon) < 0) {
                 freecon(filecon);
                 return -1;
             }
@@ -1558,6 +1572,7 @@ virStorageBackendStablePath(virStoragePoolObjPtr pool,
     char *stablepath;
     int opentries = 0;
     int retry = 0;
+    int direrr;
 
     /* Short circuit if pool has no target, or if its /dev */
     if (pool->def->target.path == NULL ||
@@ -1598,10 +1613,11 @@ virStorageBackendStablePath(virStoragePoolObjPtr pool,
      * to this device node.
      *
      * And it might need some time till the stable path shows
-     * up, so add timeout to retry here.
+     * up, so add timeout to retry here.  Ignore readdir failures,
+     * since we have a fallback.
      */
  retry:
-    while ((dent = readdir(dh)) != NULL) {
+    while ((direrr = virDirRead(dh, &dent, NULL)) > 0) {
         if (dent->d_name[0] == '.')
             continue;
 
@@ -1620,7 +1636,7 @@ virStorageBackendStablePath(virStoragePoolObjPtr pool,
         VIR_FREE(stablepath);
     }
 
-    if (loop && ++retry < 100) {
+    if (!direrr && loop && ++retry < 100) {
         usleep(100 * 1000);
         goto retry;
     }
@@ -1636,3 +1652,92 @@ virStorageBackendStablePath(virStoragePoolObjPtr pool,
 
     return stablepath;
 }
+
+#ifdef GLUSTER_CLI
+int
+virStorageBackendFindGlusterPoolSources(const char *host,
+                                        int pooltype,
+                                        virStoragePoolSourceListPtr list)
+{
+    char *outbuf = NULL;
+    virCommandPtr cmd = NULL;
+    xmlDocPtr doc = NULL;
+    xmlXPathContextPtr ctxt = NULL;
+    xmlNodePtr *nodes = NULL;
+    virStoragePoolSource *src = NULL;
+    size_t i;
+    int nnodes;
+    int rc;
+
+    int ret = -1;
+
+    cmd = virCommandNewArgList(GLUSTER_CLI,
+                               "--xml",
+                               "--log-file=/dev/null",
+                               "volume", "info", "all", NULL);
+
+    virCommandAddArgFormat(cmd, "--remote-host=%s", host);
+    virCommandSetOutputBuffer(cmd, &outbuf);
+
+    if (virCommandRun(cmd, &rc) < 0)
+        goto cleanup;
+
+    if (rc != 0) {
+        VIR_INFO("failed to query host '%s' for gluster volumes: %s",
+                 host, outbuf);
+        ret = 0;
+        goto cleanup;
+    }
+
+    if (!(doc = virXMLParseStringCtxt(outbuf, _("(gluster_cli_output)"),
+                                      &ctxt)))
+        goto cleanup;
+
+    if ((nnodes = virXPathNodeSet("//volumes/volume", ctxt, &nodes)) <= 0) {
+        VIR_INFO("no gluster volumes available on '%s'", host);
+        ret = 0;
+        goto cleanup;
+    }
+
+    for (i = 0; i < nnodes; i++) {
+        ctxt->node = nodes[i];
+
+        if (!(src = virStoragePoolSourceListNewSource(list)))
+            goto cleanup;
+
+        if (!(src->dir = virXPathString("string(//name)", ctxt))) {
+            virReportError(VIR_ERR_INTERNAL_ERROR, "%s",
+                           _("failed to extract gluster volume name"));
+            goto cleanup;
+        }
+
+        if (VIR_ALLOC_N(src->hosts, 1) < 0)
+            goto cleanup;
+        src->nhost = 1;
+
+        if (VIR_STRDUP(src->hosts[0].name, host) < 0)
+            goto cleanup;
+
+        src->format = pooltype;
+    }
+
+    ret = 0;
+
+ cleanup:
+    VIR_FREE(nodes);
+    xmlXPathFreeContext(ctxt);
+    xmlFreeDoc(doc);
+    VIR_FREE(outbuf);
+    virCommandFree(cmd);
+    return ret;
+}
+#else /* #ifdef GLUSTER_CLI */
+int
+virStorageBackendFindGlusterPoolSources(const char *host ATTRIBUTE_UNUSED,
+                                        int pooltype ATTRIBUTE_UNUSED,
+                                        virStoragePoolSourceListPtr list ATTRIBUTE_UNUSED)
+{
+    VIR_INFO("gluster cli tool not installed");
+    return 0;
+}
+#endif /* #ifdef GLUSTER_CLI */
