@@ -1,7 +1,7 @@
 /*
  * storage_backend_rbd.c: storage backend for RBD (RADOS Block Device) handling
  *
- * Copyright (C) 2013 Red Hat, Inc.
+ * Copyright (C) 2013-2014 Red Hat, Inc.
  * Copyright (C) 2012 Wido den Hollander
  *
  * This library is free software; you can redistribute it and/or
@@ -300,8 +300,8 @@ static int volStorageBackendRBDRefreshVolInfo(virStorageVolDefPtr vol,
               (unsigned long long)info.obj_size,
               (unsigned long long)info.num_objs);
 
-    vol->capacity = info.size;
-    vol->allocation = info.obj_size * info.num_objs;
+    vol->target.capacity = info.size;
+    vol->target.allocation = info.obj_size * info.num_objs;
     vol->type = VIR_STORAGE_VOL_NETWORK;
 
     VIR_FREE(vol->target.path);
@@ -492,7 +492,7 @@ static int virStorageBackendRBDCreateImage(rados_ioctx_t io,
     uint64_t stripe_unit = 4194304;
 
     if (rbd_create3(io, name, capacity, features, &order,
-                    stripe_count, stripe_unit) < 0) {
+                    stripe_unit, stripe_count) < 0) {
 #else
     if (rbd_create(io, name, capacity, &order) < 0) {
 #endif
@@ -516,7 +516,7 @@ virStorageBackendRBDBuildVol(virConnectPtr conn,
 
     VIR_DEBUG("Creating RBD image %s/%s with size %llu",
               pool->def->source.name,
-              vol->name, vol->capacity);
+              vol->name, vol->target.capacity);
 
     virCheckFlags(0, -1);
 
@@ -532,7 +532,8 @@ virStorageBackendRBDBuildVol(virConnectPtr conn,
         goto cleanup;
     }
 
-    r = virStorageBackendRBDCreateImage(ptr.ioctx, vol->name, vol->capacity);
+    r = virStorageBackendRBDCreateImage(ptr.ioctx, vol->name,
+                                        vol->target.capacity);
     if (r < 0) {
         virReportSystemError(-r, _("failed to create volume '%s/%s'"),
                              pool->def->source.name,
