@@ -315,13 +315,16 @@ xenUnifiedProbe(void)
 static bool
 xenUnifiedXendProbe(void)
 {
-    virCommandPtr cmd;
     bool ret = false;
 
-    cmd = virCommandNewArgList("/usr/sbin/xend", "status", NULL);
-    if (virCommandRun(cmd, NULL) == 0)
-        ret = true;
-    virCommandFree(cmd);
+    if (virFileExists("/usr/sbin/xend")) {
+        virCommandPtr cmd;
+
+        cmd = virCommandNewArgList("/usr/sbin/xend", "status", NULL);
+        if (virCommandRun(cmd, NULL) == 0)
+            ret = true;
+        virCommandFree(cmd);
+    }
 
     return ret;
 }
@@ -2424,7 +2427,7 @@ xenUnifiedConnectDomainEventDeregisterAny(virConnectPtr conn,
 
 
 static int
-xenUnifiedNodeDeviceGetPciInfo(virNodeDevicePtr dev,
+xenUnifiedNodeDeviceGetPCIInfo(virNodeDevicePtr dev,
                                unsigned *domain,
                                unsigned *bus,
                                unsigned *slot,
@@ -2480,7 +2483,7 @@ xenUnifiedNodeDeviceDetachFlags(virNodeDevicePtr dev,
 
     virCheckFlags(0, -1);
 
-    if (xenUnifiedNodeDeviceGetPciInfo(dev, &domain, &bus, &slot, &function) < 0)
+    if (xenUnifiedNodeDeviceGetPCIInfo(dev, &domain, &bus, &slot, &function) < 0)
         return -1;
 
     pci = virPCIDeviceNew(domain, bus, slot, function);
@@ -2538,7 +2541,7 @@ xenUnifiedNodeDeviceAssignedDomainId(virNodeDevicePtr dev)
     }
 
     /* Get pci bdf */
-    if (xenUnifiedNodeDeviceGetPciInfo(dev, &domain, &bus, &slot, &function) < 0)
+    if (xenUnifiedNodeDeviceGetPCIInfo(dev, &domain, &bus, &slot, &function) < 0)
         goto out;
 
     if (virAsprintf(&bdf, "%04x:%02x:%02x.%0x",
@@ -2574,7 +2577,7 @@ xenUnifiedNodeDeviceReAttach(virNodeDevicePtr dev)
     int ret = -1;
     int domid;
 
-    if (xenUnifiedNodeDeviceGetPciInfo(dev, &domain, &bus, &slot, &function) < 0)
+    if (xenUnifiedNodeDeviceGetPCIInfo(dev, &domain, &bus, &slot, &function) < 0)
         return -1;
 
     pci = virPCIDeviceNew(domain, bus, slot, function);
@@ -2605,7 +2608,7 @@ xenUnifiedNodeDeviceReset(virNodeDevicePtr dev)
     unsigned domain, bus, slot, function;
     int ret = -1;
 
-    if (xenUnifiedNodeDeviceGetPciInfo(dev, &domain, &bus, &slot, &function) < 0)
+    if (xenUnifiedNodeDeviceGetPCIInfo(dev, &domain, &bus, &slot, &function) < 0)
         return -1;
 
     pci = virPCIDeviceNew(domain, bus, slot, function);
