@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2011-2013 Red Hat, Inc.
+ * Copyright (C) 2011-2014 Red Hat, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -1356,8 +1356,8 @@ testQemuMonitorJSONqemuMonitorJSONGetBlockInfo(const void *data)
     if (!test)
         return -1;
 
-    if (!(blockDevices = virHashCreate(32, (virHashDataFree) free)) ||
-        !(expectedBlockDevices = virHashCreate(32, (virHashDataFree) (free))))
+    if (!(blockDevices = virHashCreate(32, virHashValueFree)) ||
+        !(expectedBlockDevices = virHashCreate(32, virHashValueFree)))
         goto cleanup;
 
     if (VIR_ALLOC(info) < 0)
