@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2011 Red Hat, Inc.
+ * Copyright (C) 2011, 2013 Red Hat, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -22,13 +22,14 @@
 
 #include <stdio.h>
 #include "internal.h"
+#define NO_LIBVIRT /* This file intentionally does not link to libvirt */
 #include "testutils.h"
 
 #ifndef WIN32
 
 int main(int argc, char **argv)
 {
-    int i;
+    size_t i;
     bool failConnect = false; /* Exit -1, with no data on stdout, msg on stderr */
     bool dieEarly = false;    /* Exit -1, with partial data on stdout, msg on stderr */
 
