@@ -23,8 +23,11 @@
 #include "virfile.h"
 #include "testutils.h"
 
-#if HAVE_DLFCN_H && defined(RTLD_NEXT)
+#if HAVE_DLFCN_H
+# include <dlfcn.h>
+#endif
 
+#if defined(RTLD_NEXT)
 # ifdef MOCK_HELPER
 #  include "internal.h"
 #  include <sys/socket.h>
@@ -32,7 +35,6 @@
 #  include <arpa/inet.h>
 #  include <netinet/in.h>
 #  include <stdio.h>
-#  include <dlfcn.h>
 
 static bool host_has_ipv6 = false;
 static int (*realsocket)(int domain, int type, int protocol);
@@ -116,6 +118,7 @@ int bind(int sockfd ATTRIBUTE_UNUSED,
 
 #  define VIR_FROM_THIS VIR_FROM_RPC
 
+VIR_LOG_INIT("tests.portallocatortest");
 
 static int testAllocAll(const void *args ATTRIBUTE_UNUSED)
 {
@@ -181,7 +184,7 @@ static int testAllocAll(const void *args ATTRIBUTE_UNUSED)
     }
 
     ret = 0;
-cleanup:
+ cleanup:
     virObjectUnref(alloc);
     return ret;
 }
@@ -234,7 +237,7 @@ static int testAllocReuse(const void *args ATTRIBUTE_UNUSED)
     }
 
     ret = 0;
-cleanup:
+ cleanup:
     virObjectUnref(alloc);
     return ret;
 }
@@ -259,13 +262,13 @@ mymain(void)
     if (virtTestRun("Test IPv4-only alloc reuse", testAllocReuse, NULL) < 0)
         ret = -1;
 
-    return ret==0 ? EXIT_SUCCESS : EXIT_FAILURE;
+    return ret == 0 ? EXIT_SUCCESS : EXIT_FAILURE;
 }
 
 VIRT_TEST_MAIN_PRELOAD(mymain, abs_builddir "/.libs/libvirportallocatormock.so")
 # endif
 
-#else /* ! HAVE_DLFCN_H */
+#else /* ! defined(RTLD_NEXT) */
 int
 main(void)
 {
