@@ -99,7 +99,7 @@ vshSnapshotCreate(vshControl *ctl, virDomainPtr dom, const char *buffer,
 
     ret = true;
 
-cleanup:
+ cleanup:
     xmlXPathFreeContext(ctxt);
     xmlFreeDoc(xml);
     if (snapshot)
@@ -214,7 +214,7 @@ cmdSnapshotCreate(vshControl *ctl, const vshCmd *cmd)
 
     ret = vshSnapshotCreate(ctl, dom, buffer, flags, from);
 
-cleanup:
+ cleanup:
     VIR_FREE(buffer);
     if (dom)
         virDomainFree(dom);
@@ -253,12 +253,12 @@ vshParseSnapshotMemspec(vshControl *ctl, virBufferPtr buf, const char *str)
             goto cleanup;
     }
 
-    virBufferAddLit(buf, "  <memory");
+    virBufferAddLit(buf, "<memory");
     virBufferEscapeString(buf, " snapshot='%s'", snapshot);
     virBufferEscapeString(buf, " file='%s'", file);
     virBufferAddLit(buf, "/>\n");
     ret = 0;
-cleanup:
+ cleanup:
     if (ret < 0)
         vshError(ctl, _("unable to parse memspec: %s"), str);
     virStringFreeList(array);
@@ -293,21 +293,23 @@ vshParseSnapshotDiskspec(vshControl *ctl, virBufferPtr buf, const char *str)
             goto cleanup;
     }
 
-    virBufferEscapeString(buf, "    <disk name='%s'", name);
+    virBufferEscapeString(buf, "<disk name='%s'", name);
     if (snapshot)
         virBufferAsprintf(buf, " snapshot='%s'", snapshot);
     if (driver || file) {
         virBufferAddLit(buf, ">\n");
+        virBufferAdjustIndent(buf, 2);
         if (driver)
-            virBufferAsprintf(buf, "      <driver type='%s'/>\n", driver);
+            virBufferAsprintf(buf, "<driver type='%s'/>\n", driver);
         if (file)
-            virBufferEscapeString(buf, "      <source file='%s'/>\n", file);
-        virBufferAddLit(buf, "    </disk>\n");
+            virBufferEscapeString(buf, "<source file='%s'/>\n", file);
+        virBufferAdjustIndent(buf, -2);
+        virBufferAddLit(buf, "</disk>\n");
     } else {
         virBufferAddLit(buf, "/>\n");
     }
     ret = 0;
-cleanup:
+ cleanup:
     if (ret < 0)
         vshError(ctl, _("unable to parse diskspec: %s"), str);
     virStringFreeList(array);
@@ -424,8 +426,9 @@ cmdSnapshotCreateAs(vshControl *ctl, const vshCmd *cmd)
         goto cleanup;
 
     virBufferAddLit(&buf, "<domainsnapshot>\n");
-    virBufferEscapeString(&buf, "  <name>%s</name>\n", name);
-    virBufferEscapeString(&buf, "  <description>%s</description>\n", desc);
+    virBufferAdjustIndent(&buf, 2);
+    virBufferEscapeString(&buf, "<name>%s</name>\n", name);
+    virBufferEscapeString(&buf, "<description>%s</description>\n", desc);
 
     if (vshCommandOptStringReq(ctl, cmd, "memspec", &memspec) < 0)
         goto cleanup;
@@ -434,13 +437,16 @@ cmdSnapshotCreateAs(vshControl *ctl, const vshCmd *cmd)
         goto cleanup;
 
     if (vshCommandOptBool(cmd, "diskspec")) {
-        virBufferAddLit(&buf, "  <disks>\n");
+        virBufferAddLit(&buf, "<disks>\n");
+        virBufferAdjustIndent(&buf, 2);
         while ((opt = vshCommandOptArgv(cmd, opt))) {
             if (vshParseSnapshotDiskspec(ctl, &buf, opt->data) < 0)
                 goto cleanup;
         }
-        virBufferAddLit(&buf, "  </disks>\n");
+        virBufferAdjustIndent(&buf, -2);
+        virBufferAddLit(&buf, "</disks>\n");
     }
+    virBufferAdjustIndent(&buf, -2);
     virBufferAddLit(&buf, "</domainsnapshot>\n");
 
     if (virBufferError(&buf)) {
@@ -458,7 +464,7 @@ cmdSnapshotCreateAs(vshControl *ctl, const vshCmd *cmd)
 
     ret = vshSnapshotCreate(ctl, dom, buffer, flags, NULL);
 
-cleanup:
+ cleanup:
     virBufferFreeAndReset(&buf);
     VIR_FREE(buffer);
     virDomainFree(dom);
@@ -614,7 +620,7 @@ cmdSnapshotEdit(vshControl *ctl, const vshCmd *cmd)
 
     ret = true;
 
-cleanup:
+ cleanup:
     if (!ret && name)
         vshError(ctl, _("Failed to update %s"), name);
     if (edited)
@@ -733,7 +739,7 @@ cmdSnapshotCurrent(vshControl *ctl, const vshCmd *cmd)
 
     ret = true;
 
-cleanup:
+ cleanup:
     if (!ret)
         vshReportError(ctl);
     VIR_FREE(xml);
@@ -789,7 +795,7 @@ vshGetSnapshotParent(vshControl *ctl, virDomainSnapshotPtr snapshot,
     *parent_name = virXPathString("string(/domainsnapshot/parent/name)", ctxt);
     ret = 0;
 
-cleanup:
+ cleanup:
     if (ret < 0) {
         vshReportError(ctl);
         vshError(ctl, "%s", _("unable to determine if snapshot has parent"));
@@ -853,7 +859,7 @@ vshSnapshotFilter(vshControl *ctl, virDomainSnapshotPtr snapshot,
             ret = !!(flags & VIR_DOMAIN_SNAPSHOT_LIST_ACTIVE);
     }
 
-cleanup:
+ cleanup:
     VIR_FREE(state);
     xmlXPathFreeContext(ctxt);
     xmlFreeDoc(xmldoc);
@@ -1024,7 +1030,7 @@ cmdSnapshotInfo(vshControl *ctl, const vshCmd *cmd)
 
     ret = true;
 
-cleanup:
+ cleanup:
     VIR_FREE(state);
     xmlXPathFreeContext(ctxt);
     xmlFreeDoc(xmldoc);
@@ -1369,7 +1375,7 @@ vshSnapshotListCollect(vshControl *ctl, virDomainPtr dom,
         }
     }
 
-success:
+ success:
     if (filter_fallback) {
         /* Older API didn't filter on status or location, but the
          * information is available in domain XML.  */
@@ -1400,7 +1406,7 @@ success:
     ret = snaplist;
     snaplist = NULL;
 
-cleanup:
+ cleanup:
     vshSnapshotListFree(snaplist);
     if (names && count > 0)
         for (i = 0; i < count; i++)
@@ -1667,7 +1673,7 @@ cmdSnapshotList(vshControl *ctl, const vshCmd *cmd)
 
     ret = true;
 
-cleanup:
+ cleanup:
     /* this frees up memory from the last iteration of the loop */
     vshSnapshotListFree(snaplist);
     VIR_FREE(parent_snap);
@@ -1741,7 +1747,7 @@ cmdSnapshotDumpXML(vshControl *ctl, const vshCmd *cmd)
     vshPrint(ctl, "%s", xml);
     ret = true;
 
-cleanup:
+ cleanup:
     VIR_FREE(xml);
     if (snapshot)
         virDomainSnapshotFree(snapshot);
@@ -1808,7 +1814,7 @@ cmdSnapshotParent(vshControl *ctl, const vshCmd *cmd)
 
     ret = true;
 
-cleanup:
+ cleanup:
     VIR_FREE(parent);
     if (snapshot)
         virDomainSnapshotFree(snapshot);
@@ -1902,7 +1908,7 @@ cmdDomainSnapshotRevert(vshControl *ctl, const vshCmd *cmd)
 
     ret = true;
 
-cleanup:
+ cleanup:
     if (snapshot)
         virDomainSnapshotFree(snapshot);
     if (dom)
@@ -1992,7 +1998,7 @@ cmdSnapshotDelete(vshControl *ctl, const vshCmd *cmd)
 
     ret = true;
 
-cleanup:
+ cleanup:
     if (snapshot)
         virDomainSnapshotFree(snapshot);
     if (dom)
