@@ -60,8 +60,16 @@ vshCommandOptVolBy(vshControl *ctl, const vshCmd *cmd,
         vshCommandOptStringReq(ctl, cmd, pooloptname, &p) < 0)
         return NULL;
 
-    if (p)
-        pool = vshCommandOptPoolBy(ctl, cmd, pooloptname, name, flags);
+    if (p) {
+        if (!(pool = vshCommandOptPoolBy(ctl, cmd, pooloptname, name, flags)))
+            return NULL;
+
+        if (virStoragePoolIsActive(pool) != 1) {
+            vshError(ctl, _("pool '%s' is not active"), p);
+            virStoragePoolFree(pool);
+            return NULL;
+        }
+    }
 
     vshDebug(ctl, VSH_ERR_DEBUG, "%s: found option <%s>: %s\n",
              cmd->def->name, optname, n);
@@ -204,15 +212,18 @@ cmdVolCreateAs(vshControl *ctl, const vshCmd *cmd)
         goto cleanup;
 
     virBufferAddLit(&buf, "<volume>\n");
-    virBufferAsprintf(&buf, "  <name>%s</name>\n", name);
-    virBufferAsprintf(&buf, "  <capacity>%llu</capacity>\n", capacity);
+    virBufferAdjustIndent(&buf, 2);
+    virBufferAsprintf(&buf, "<name>%s</name>\n", name);
+    virBufferAsprintf(&buf, "<capacity>%llu</capacity>\n", capacity);
     if (allocationStr)
-        virBufferAsprintf(&buf, "  <allocation>%llu</allocation>\n", allocation);
+        virBufferAsprintf(&buf, "<allocation>%llu</allocation>\n", allocation);
 
     if (format) {
-        virBufferAddLit(&buf, "  <target>\n");
-        virBufferAsprintf(&buf, "    <format type='%s'/>\n", format);
-        virBufferAddLit(&buf, "  </target>\n");
+        virBufferAddLit(&buf, "<target>\n");
+        virBufferAdjustIndent(&buf, 2);
+        virBufferAsprintf(&buf, "<format type='%s'/>\n", format);
+        virBufferAdjustIndent(&buf, -2);
+        virBufferAddLit(&buf, "</target>\n");
     }
 
     /* Convert the snapshot parameters into backingStore XML */
@@ -264,18 +275,21 @@ cmdVolCreateAs(vshControl *ctl, const vshCmd *cmd)
         }
 
         /* Create XML for the backing store */
-        virBufferAddLit(&buf, "  <backingStore>\n");
-        virBufferAsprintf(&buf, "    <path>%s</path>\n", snapshotStrVolPath);
+        virBufferAddLit(&buf, "<backingStore>\n");
+        virBufferAdjustIndent(&buf, 2);
+        virBufferAsprintf(&buf, "<path>%s</path>\n", snapshotStrVolPath);
         if (snapshotStrFormat)
-            virBufferAsprintf(&buf, "    <format type='%s'/>\n",
+            virBufferAsprintf(&buf, "<format type='%s'/>\n",
                               snapshotStrFormat);
-        virBufferAddLit(&buf, "  </backingStore>\n");
+        virBufferAdjustIndent(&buf, -2);
+        virBufferAddLit(&buf, "</backingStore>\n");
 
         /* Cleanup snapshot allocations */
         VIR_FREE(snapshotStrVolPath);
         virStorageVolFree(snapVol);
     }
 
+    virBufferAdjustIndent(&buf, -2);
     virBufferAddLit(&buf, "</volume>\n");
 
     if (virBufferError(&buf)) {
@@ -365,7 +379,7 @@ cmdVolCreate(vshControl *ctl, const vshCmd *cmd)
         vshError(ctl, _("Failed to create vol from %s"), from);
     }
 
-cleanup:
+ cleanup:
     VIR_FREE(buffer);
     virStoragePoolFree(pool);
     return ret;
@@ -449,7 +463,7 @@ cmdVolCreateFrom(vshControl *ctl, const vshCmd *cmd)
     }
 
     ret = true;
-cleanup:
+ cleanup:
     VIR_FREE(buffer);
     if (pool)
         virStoragePoolFree(pool);
@@ -482,7 +496,7 @@ vshMakeCloneXML(const char *origxml, const char *newname)
     xmlNodeSetContent(obj->nodesetval->nodeTab[0], (const xmlChar *)newname);
     xmlDocDumpMemory(doc, &newxml, &size);
 
-cleanup:
+ cleanup:
     xmlXPathFreeObject(obj);
     xmlXPathFreeContext(ctxt);
     xmlFreeDoc(doc);
@@ -573,7 +587,7 @@ cmdVolClone(vshControl *ctl, const vshCmd *cmd)
 
     ret = true;
 
-cleanup:
+ cleanup:
     VIR_FREE(origxml);
     xmlFree(newxml);
     if (origvol)
@@ -694,7 +708,7 @@ cmdVolUpload(vshControl *ctl, const vshCmd *cmd)
 
     ret = true;
 
-cleanup:
+ cleanup:
     if (vol)
         virStorageVolFree(vol);
     if (st)
@@ -808,7 +822,7 @@ cmdVolDownload(vshControl *ctl, const vshCmd *cmd)
 
     ret = true;
 
-cleanup:
+ cleanup:
     VIR_FORCE_CLOSE(fd);
     if (!ret && created)
         unlink(file);
@@ -938,7 +952,7 @@ cmdVolWipe(vshControl *ctl, const vshCmd *cmd)
 
     vshPrint(ctl, _("Vol %s wiped\n"), name);
     ret = true;
-out:
+ out:
     virStorageVolFree(vol);
     return ret;
 }
@@ -1117,7 +1131,7 @@ cmdVolResize(vshControl *ctl, const vshCmd *cmd)
         ret = false;
     }
 
-cleanup:
+ cleanup:
     virStorageVolFree(vol);
     return ret;
 }
@@ -1237,7 +1251,7 @@ vshStorageVolListCollect(vshControl *ctl,
     vshError(ctl, "%s", _("Failed to list volumes"));
     goto cleanup;
 
-fallback:
+ fallback:
     /* fall back to old method (0.10.1 and older) */
     vshResetLibvirtError();
 
@@ -1272,7 +1286,7 @@ fallback:
     /* truncate the list for not found vols */
     deleted = nvols - list->nvols;
 
-finished:
+ finished:
     /* sort the list */
     if (list->vols && list->nvols)
         qsort(list->vols, list->nvols, sizeof(*list->vols), vshStorageVolSorter);
@@ -1282,7 +1296,7 @@ finished:
 
     success = true;
 
-cleanup:
+ cleanup:
     if (nvols > 0)
         for (i = 0; i < nvols; i++)
             VIR_FREE(names[i]);
@@ -1515,7 +1529,7 @@ cmdVolList(vshControl *ctl, const vshCmd *cmd ATTRIBUTE_UNUSED)
     /* Cleanup and return */
     ret = true;
 
-cleanup:
+ cleanup:
 
     /* Safely free the memory allocated in this function */
     if (list && list->nvols) {
